from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Priority:
	"""Priority commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("priority", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.PrioMode:
		"""SCPI: ARBitrary:PRIority:MODE \n
		Snippet: value: enums.PrioMode = driver.arbitrary.priority.get_mode() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:PRIority:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PrioMode)

	def set_mode(self, arg_0: enums.PrioMode) -> None:
		"""SCPI: ARBitrary:PRIority:MODE \n
		Snippet: driver.arbitrary.priority.set_mode(arg_0 = enums.PrioMode.CPM) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.PrioMode)
		self._core.io.write(f'ARBitrary:PRIority:MODE {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal.Types import DataType
from ..Internal.ArgSingleList import ArgSingleList
from ..Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Apply:
	"""Apply commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("apply", core, parent)

	def set(self, voltage: float, current: float, output: bool) -> None:
		"""SCPI: APPLy \n
		Snippet: driver.apply.set(voltage = 1.0, current = 1.0, output = False) \n
		Sets or queries the voltage and current value of the selected channel. \n
			:param voltage:
				- numeric: Numeric value for voltage in the range of 0.000 to 64.050.
				- MIN | MINimum: Min voltage at 0.000 V.
				- MAX | MAXimum: Max value for voltage at 64.050V.
				- DEF | DEFault: Default voltage.
			:param current:
				- numeric: Numeric value for current in the range of 0.000 to 20.0100.
				- MIN | MINimum: Min current at 0.000 A.
				- MAX | MAXimum: Max value for current at 0.0100 A.
				- DEF | DEFault: Numeric value for current.
			:param output:
				- OUT1 | OUTP1 | OUTPut1 | CH1: Selects output for channel 1.
				- OUT2 | OUTP2 | OUTPut2 | CH2: Selects output for channel 2.
				- OUT3 | OUTP3 | OUTPut3 | CH3: Selects output for channel 2.
				- OUT4 | OUTP4 | OUTPut4 | CH4: Selects output for channel 4."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('voltage', voltage, DataType.Float), ArgSingle('current', current, DataType.Float), ArgSingle('output', output, DataType.Boolean))
		self._core.io.write_with_opc(f'APPLy {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Wlan:
	"""Wlan commands group definition. 9 total commands, 2 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wlan", core, parent)

	@property
	def connection(self):
		"""connection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_connection'):
			from .Connection import Connection
			self._connection = Connection(self._core, self._cmd_group)
		return self._connection

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import Apply
			self._apply = Apply(self._core, self._cmd_group)
		return self._apply

	def get_state(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:WLAN[:STATe] \n
		Snippet: value: bool = driver.system.communicate.wlan.get_state() \n
		Enables or disables WLAN state. Available only if option R&S NGP-K102. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN[:STATe] \n
		Snippet: driver.system.communicate.wlan.set_state(arg_0 = False) \n
		Enables or disables WLAN state. Available only if option R&S NGP-K102. \n
			:param arg_0:
				- 1: Enable WLAN.
				- 0: Disable WLAN."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:STATe {param}')

	def get_ssid(self) -> str:
		"""SCPI: SYSTem:COMMunicate:WLAN:SSID \n
		Snippet: value: str = driver.system.communicate.wlan.get_ssid() \n
		Sets or queries SSID of the access point when wireless interface works as a client. Available only if option R&S NGP-K102. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:SSID?')
		return trim_str_response(response)

	def set_ssid(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:SSID \n
		Snippet: driver.system.communicate.wlan.set_ssid(arg_0 = '1') \n
		Sets or queries SSID of the access point when wireless interface works as a client. Available only if option R&S NGP-K102. \n
			:param arg_0: SSID of access point.
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:SSID {param}')

	def set_password(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:PASSword \n
		Snippet: driver.system.communicate.wlan.set_password(arg_0 = '1') \n
		Sets or queries password for WLAN. Available only if option R&S NGP-K102. \n
			:param arg_0: WLAN password.
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:PASSword {param}')

	def get_dhcp(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:WLAN:DHCP \n
		Snippet: value: bool = driver.system.communicate.wlan.get_dhcp() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:DHCP?')
		return Conversions.str_to_bool(response)

	def set_dhcp(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:DHCP \n
		Snippet: driver.system.communicate.wlan.set_dhcp(arg_0 = False) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:DHCP {param}')

	def get_ip_address(self) -> str:
		"""SCPI: SYSTem:COMMunicate:WLAN:IPADdress \n
		Snippet: value: str = driver.system.communicate.wlan.get_ip_address() \n
		Queries IP address for WLAN. Available only if option R&S NGP-K102. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:IPADdress?')
		return trim_str_response(response)

	def set_ip_address(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:IPADdress \n
		Snippet: driver.system.communicate.wlan.set_ip_address(arg_0 = '1') \n
		Queries IP address for WLAN. Available only if option R&S NGP-K102. \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:IPADdress {param}')

	def get_mask(self) -> str:
		"""SCPI: SYSTem:COMMunicate:WLAN:MASK \n
		Snippet: value: str = driver.system.communicate.wlan.get_mask() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:MASK?')
		return trim_str_response(response)

	def set_mask(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:MASK \n
		Snippet: driver.system.communicate.wlan.set_mask(arg_0 = '1') \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:MASK {param}')

	def get_gateway(self) -> str:
		"""SCPI: SYSTem:COMMunicate:WLAN:GATeway \n
		Snippet: value: str = driver.system.communicate.wlan.get_gateway() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:WLAN:GATeway?')
		return trim_str_response(response)

	def set_gateway(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:WLAN:GATeway \n
		Snippet: driver.system.communicate.wlan.set_gateway(arg_0 = '1') \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:WLAN:GATeway {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fault:
	"""Fault commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fault", core, parent)

	def get_state(self) -> bool:
		"""SCPI: DIO:FAULt[:STATe] \n
		Snippet: value: bool = driver.dio.fault.get_state() \n
		Sets or queries the digital output fault. See 'operation modes' in Figure 'Overview of trigger IO system' \n
			:return: arg_0: 1 Enables digital output fault. 0 Disables digital output fault.
		"""
		response = self._core.io.query_str('DIO:FAULt:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: DIO:FAULt[:STATe] \n
		Snippet: driver.dio.fault.set_state(arg_0 = False) \n
		Sets or queries the digital output fault. See 'operation modes' in Figure 'Overview of trigger IO system' \n
			:param arg_0: 1 Enables digital output fault. 0 Disables digital output fault.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'DIO:FAULt:STATe {param}')

	def get_channel(self) -> int:
		"""SCPI: DIO:FAULt:CHANnel \n
		Snippet: value: int = driver.dio.fault.get_channel() \n
		Sets or queries channel selection for the digital output fault source. See 'operation modes' in Figure 'Overview of
		trigger IO system'. \n
			:return: arg_0: 1 | 2
		"""
		response = self._core.io.query_str('DIO:FAULt:CHANnel?')
		return Conversions.str_to_int(response)

	def set_channel(self, arg_0: int) -> None:
		"""SCPI: DIO:FAULt:CHANnel \n
		Snippet: driver.dio.fault.set_channel(arg_0 = 1) \n
		Sets or queries channel selection for the digital output fault source. See 'operation modes' in Figure 'Overview of
		trigger IO system'. \n
			:param arg_0: 1 | 2
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'DIO:FAULt:CHANnel {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.DioFaultSource:
		"""SCPI: DIO:FAULt:SOURce \n
		Snippet: value: enums.DioFaultSource = driver.dio.fault.get_source() \n
		Sets or queries the 'operation modes' of the digital output fault source See 'operation modes' in Figure 'Overview of
		trigger IO system'. \n
			:return: arg_0: CC | CV | CR | SINK | PROTection | OUTPut If 'OUTPut' is selected, the 'fault output' will be active if the output of the selected channel is off.
		"""
		response = self._core.io.query_str('DIO:FAULt:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.DioFaultSource)

	def set_source(self, arg_0: enums.DioFaultSource) -> None:
		"""SCPI: DIO:FAULt:SOURce \n
		Snippet: driver.dio.fault.set_source(arg_0 = enums.DioFaultSource.CC) \n
		Sets or queries the 'operation modes' of the digital output fault source See 'operation modes' in Figure 'Overview of
		trigger IO system'. \n
			:param arg_0: CC | CV | CR | SINK | PROTection | OUTPut If 'OUTPut' is selected, the 'fault output' will be active if the output of the selected channel is off.
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.DioFaultSource)
		self._core.io.write(f'DIO:FAULt:SOURce {param}')

	# noinspection PyTypeChecker
	def get_signal(self) -> enums.DioSignal:
		"""SCPI: DIO:FAULt:SIGNal \n
		Snippet: value: enums.DioSignal = driver.dio.fault.get_signal() \n
		Select digital output fault signal type. \n
			:return: arg_0: CONStant | PULSe CONStant An constant level trigger signal is sent out PULSe An output pulse of 100 ms trigger signal is sent out
		"""
		response = self._core.io.query_str('DIO:FAULt:SIGNal?')
		return Conversions.str_to_scalar_enum(response, enums.DioSignal)

	def set_signal(self, arg_0: enums.DioSignal) -> None:
		"""SCPI: DIO:FAULt:SIGNal \n
		Snippet: driver.dio.fault.set_signal(arg_0 = enums.DioSignal.CONStant) \n
		Select digital output fault signal type. \n
			:param arg_0: CONStant | PULSe CONStant An constant level trigger signal is sent out PULSe An output pulse of 100 ms trigger signal is sent out
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.DioSignal)
		self._core.io.write(f'DIO:FAULt:SIGNal {param}')



"""RsNgx instrument driver
	:version: 3.1.0.49
	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '3.1.0.49'

# Main class
from RsNgx.RsNgx import RsNgx

# Bin data format
from RsNgx.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsNgx.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsNgx.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsNgx.Internal.ScpiLogger import LoggingMode

# enums
from RsNgx import enums

# repcaps
from RsNgx import repcap



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dc:
	"""Dc commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dc", core, parent)

	def get_max(self) -> float:
		"""SCPI: MEASure[:SCALar][:VOLTage][:DC]:MAX \n
		Snippet: value: float = driver.measure.scalar.voltage.dc.get_max() \n
		Queries the maximum measured output voltage. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:VOLTage:DC:MAX?')
		return Conversions.str_to_float(response)

	def get_avg(self) -> float:
		"""SCPI: MEASure[:SCALar][:VOLTage][:DC]:AVG \n
		Snippet: value: float = driver.measure.scalar.voltage.dc.get_avg() \n
		Queries the average measured output voltage. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:VOLTage:DC:AVG?')
		return Conversions.str_to_float(response)

	def get_min(self) -> float:
		"""SCPI: MEASure[:SCALar][:VOLTage][:DC]:MIN \n
		Snippet: value: float = driver.measure.scalar.voltage.dc.get_min() \n
		Queries the minimum measured output voltage. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:VOLTage:DC:MIN?')
		return Conversions.str_to_float(response)

	def get_statistic(self) -> float:
		"""SCPI: MEASure[:SCALar][:VOLTage][:DC]:STATistic \n
		Snippet: value: float = driver.measure.scalar.voltage.dc.get_statistic() \n
		Queries the voltage statistics of the selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:VOLTage:DC:STATistic?')
		return Conversions.str_to_float(response)

	def get_value(self) -> float:
		"""SCPI: MEASure[:SCALar][:VOLTage][:DC] \n
		Snippet: value: float = driver.measure.scalar.voltage.dc.get_value() \n
		Queries the currently measured voltage of the selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:VOLTage:DC?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Types import DataType
from ...Internal.Utilities import trim_str_response
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fname:
	"""Fname commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fname", core, parent)

	def set(self, filename: str, file_location: enums.Filename = None) -> None:
		"""SCPI: ARBitrary:FNAMe \n
		Snippet: driver.arbitrary.fname.set(filename = '1', file_location = enums.Filename.DEF) \n
		Sets or queries the file name and storage location for the QuickArb function. \n
			:param filename: Filename of the QuickArb function.
			:param file_location:
				- INT: Internal memory
				- EXT: USB stick
				- DEF: Internal memory"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('filename', filename, DataType.String), ArgSingle('file_location', file_location, DataType.Enum, enums.Filename, is_optional=True))
		self._core.io.write(f'ARBitrary:FNAMe {param}'.rstrip())

	def get(self) -> str:
		"""SCPI: ARBitrary:FNAMe \n
		Snippet: value: str = driver.arbitrary.fname.get() \n
		Sets or queries the file name and storage location for the QuickArb function. \n
			:return: filename: Filename of the QuickArb function."""
		response = self._core.io.query_str(f'ARBitrary:FNAMe?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sense:
	"""Sense commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	def get_source(self) -> str:
		"""SCPI: [SOURce]:VOLTage:SENSe[:SOURce] \n
		Snippet: value: str = driver.source.voltage.sense.get_source() \n
		Sets remote sense detection. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SOURce:VOLTage:SENSe:SOURce?')
		return trim_str_response(response)

	def set_source(self, arg_0: str) -> None:
		"""SCPI: [SOURce]:VOLTage:SENSe[:SOURce] \n
		Snippet: driver.source.voltage.sense.set_source(arg_0 = r1) \n
		Sets remote sense detection. \n
			:param arg_0:
				- AUTO: If remote sense detection is set AUTO, the detection and enabling of the voltage sense relay automatically kicks in when the connection of remote sense wires (S+, S-) to the input of the load is applied.
				- EXT: If remote sense detection is set EXT, internal voltage sense relay in the instrument is switched on and the connection of remote sense wires (S+, S- ) to the input of the load become necessary. Failure to connect remote sense can cause overvoltage or unregulated voltage output from the R&S NGP800."""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write(f'SOURce:VOLTage:SENSe:SOURce {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Protection:
	"""Protection commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("protection", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:POWer:PROTection[:STATe] \n
		Snippet: value: bool = driver.source.power.protection.get_state() \n
		Sets or queries the OPP state of the previous selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SOURce:POWer:PROTection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: [SOURce]:POWer:PROTection[:STATe] \n
		Snippet: driver.source.power.protection.set_state(arg_0 = False) \n
		Sets or queries the OPP state of the previous selected channel. \n
			:param arg_0:
				- 0: OPP is deactivated
				- 1: OPP is activated"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SOURce:POWer:PROTection:STATe {param}')

	def get_level(self) -> float:
		"""SCPI: [SOURce]:POWer:PROTection:LEVel \n
		Snippet: value: float = driver.source.power.protection.get_level() \n
		Sets or queries the overvoltage protection value of the selected channel. \n
			:return: voltage_protection: No help available
		"""
		response = self._core.io.query_str('SOURce:POWer:PROTection:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, voltage_protection: float) -> None:
		"""SCPI: [SOURce]:POWer:PROTection:LEVel \n
		Snippet: driver.source.power.protection.set_level(voltage_protection = 1.0) \n
		Sets or queries the overvoltage protection value of the selected channel. \n
			:param voltage_protection:
				- numeric value: Numeric value of the power protection level in watts.
				- MIN | MINimum: Minimum value of the power protection level at 0.00 W.
				- MAX | MAXimum: Maximum value of the power protection level at 200.00 W.
				- DEF | DEFault: Default value of the power protection level at 200.00 W."""
		param = Conversions.decimal_value_to_str(voltage_protection)
		self._core.io.write(f'SOURce:POWer:PROTection:LEVel {param}')

	def get_tripped(self) -> bool:
		"""SCPI: [SOURce]:POWer:PROTection:TRIPped \n
		Snippet: value: bool = driver.source.power.protection.get_tripped() \n
		Queries the OPP state of the selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('SOURce:POWer:PROTection:TRIPped?')
		return Conversions.str_to_bool(response)

	def clear(self) -> None:
		"""SCPI: [SOURce]:POWer:PROTection:CLEar \n
		Snippet: driver.source.power.protection.clear() \n
		Resets the OPP state of the selected channel. If an OPP event has occurred before, the reset also erases the message on
		the display. \n
		"""
		self._core.io.write(f'SOURce:POWer:PROTection:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce]:POWer:PROTection:CLEar \n
		Snippet: driver.source.power.protection.clear_with_opc() \n
		Resets the OPP state of the selected channel. If an OPP event has occurred before, the reset also erases the message on
		the display. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce:POWer:PROTection:CLEar', opc_timeout_ms)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class System:
	"""System commands group definition. 46 total commands, 12 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("system", core, parent)

	@property
	def beeper(self):
		"""beeper commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_beeper'):
			from .Beeper import Beeper
			self._beeper = Beeper(self._core, self._cmd_group)
		return self._beeper

	@property
	def touch(self):
		"""touch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_touch'):
			from .Touch import Touch
			self._touch = Touch(self._core, self._cmd_group)
		return self._touch

	@property
	def communicate(self):
		"""communicate commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_communicate'):
			from .Communicate import Communicate
			self._communicate = Communicate(self._core, self._cmd_group)
		return self._communicate

	@property
	def date(self):
		"""date commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_date'):
			from .Date import Date
			self._date = Date(self._core, self._cmd_group)
		return self._date

	@property
	def key(self):
		"""key commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_key'):
			from .Key import Key
			self._key = Key(self._core, self._cmd_group)
		return self._key

	@property
	def local(self):
		"""local commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_local'):
			from .Local import Local
			self._local = Local(self._core, self._cmd_group)
		return self._local

	@property
	def remote(self):
		"""remote commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remote'):
			from .Remote import Remote
			self._remote = Remote(self._core, self._cmd_group)
		return self._remote

	@property
	def rwLock(self):
		"""rwLock commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rwLock'):
			from .RwLock import RwLock
			self._rwLock = RwLock(self._core, self._cmd_group)
		return self._rwLock

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import Time
			self._time = Time(self._core, self._cmd_group)
		return self._time

	@property
	def restart(self):
		"""restart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_restart'):
			from .Restart import Restart
			self._restart = Restart(self._core, self._cmd_group)
		return self._restart

	@property
	def setting(self):
		"""setting commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import Setting
			self._setting = Setting(self._core, self._cmd_group)
		return self._setting

	@property
	def vnc(self):
		"""vnc commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_vnc'):
			from .Vnc import Vnc
			self._vnc = Vnc(self._core, self._cmd_group)
		return self._vnc

	def get_up_time(self) -> str:
		"""SCPI: SYSTem:UPTime \n
		Snippet: value: str = driver.system.get_up_time() \n
		Queries system uptime. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('SYSTem:UPTime?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Triggered:
	"""Triggered commands group definition. 4 total commands, 2 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("triggered", core, parent)

	@property
	def point(self):
		"""point commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_point'):
			from .Point import Point
			self._point = Point(self._core, self._cmd_group)
		return self._point

	@property
	def group(self):
		"""group commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_group'):
			from .Group import Group
			self._group = Group(self._core, self._cmd_group)
		return self._group

	def get_state(self) -> int or bool:
		"""SCPI: ARBitrary:TRIGgered[:STATe] \n
		Snippet: value: int or bool = driver.arbitrary.triggered.get_state() \n
		Sets or queries the trigger condition of the arbitrary for the selected channel. \n
			:return: arg_0: (integer or boolean) No help available
		"""
		response = self._core.io.query_str('ARBitrary:TRIGgered:STATe?')
		return Conversions.str_to_int_or_bool(response)

	def set_state(self, arg_0: int or bool) -> None:
		"""SCPI: ARBitrary:TRIGgered[:STATe] \n
		Snippet: driver.arbitrary.triggered.set_state(arg_0 = 1) \n
		Sets or queries the trigger condition of the arbitrary for the selected channel. \n
			:param arg_0: (integer or boolean)
				- OFF: There is no DIO pin that has a mode set to arbitrary for the selected channel.
				- 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8: DIO pin/s are enabled with a mode set to arbitrary for the selected channel.When DIO pin is enabled with arbitrary mode, QuickArb function of the channel assigned to that pin will be enabled when the correct voltage is applied to the DIO pin."""
		param = Conversions.decimal_or_bool_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:TRIGgered:STATe {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ArbTrigMode:
		"""SCPI: ARBitrary:TRIGgered:MODE \n
		Snippet: value: enums.ArbTrigMode = driver.arbitrary.triggered.get_mode() \n
		Sets or queries the arbitrary trigger mode of the previous selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:TRIGgered:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ArbTrigMode)

	def set_mode(self, arg_0: enums.ArbTrigMode) -> None:
		"""SCPI: ARBitrary:TRIGgered:MODE \n
		Snippet: driver.arbitrary.triggered.set_mode(arg_0 = enums.ArbTrigMode.RUN) \n
		Sets or queries the arbitrary trigger mode of the previous selected channel. \n
			:param arg_0: SINGle | RUN SINGle A trigger event starts only with one arbitrary sequence. RUN A trigger event starts the whole arbitrary sequences (with all repetitions) .
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.ArbTrigMode)
		self._core.io.write(f'ARBitrary:TRIGgered:MODE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voc:
	"""Voc commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("voc", core, parent)

	def get_full(self) -> float:
		"""SCPI: BATTery:SIMulator:VOC:FULL \n
		Snippet: value: float = driver.battery.simulator.voc.get_full() \n
		Queries the open circuit voltage (Voc) for full SoC, i.e SoC = 100 %. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:VOC:FULL?')
		return Conversions.str_to_float(response)

	def get_empty(self) -> float:
		"""SCPI: BATTery:SIMulator:VOC:EMPTy \n
		Snippet: value: float = driver.battery.simulator.voc.get_empty() \n
		Queries the open circuit voltage (Voc) for empty SoC, i.e SoC = 0 %. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:VOC:EMPTy?')
		return Conversions.str_to_float(response)

	def get_value(self) -> float:
		"""SCPI: BATTery:SIMulator:VOC \n
		Snippet: value: float = driver.battery.simulator.voc.get_value() \n
		Queries the open circuit voltage (Voc) . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('BATTery:SIMulator:VOC?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Channel:
	"""Channel commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("channel", core, parent)

	def set(self, arg_0: int) -> None:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce:OMODe:CHANnel \n
		Snippet: driver.trigger.sequence.immediate.source.omode.channel.set(arg_0 = 1) \n
		Sets or queries the device channel for trigger source 'Operation Modes'. See Figure 'Overview of trigger IO system'. \n
			:param arg_0: OUT1 | OUTP1 | OUTPut1 | OUT2 | OUTP2 | OUTPut2 OUT1 | OUTP1 | OUTPut1 Ch1 is selected as the device channel for trigger source. OUT2 | OUTP2 | OUTPut2 Ch2 is selected as the device channel for trigger source.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'TRIGger:SEQuence:IMMediate:SOURce:OMODe:CHANnel {param}')

	def get(self, arg_0: int) -> int:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce:OMODe:CHANnel \n
		Snippet: value: int = driver.trigger.sequence.immediate.source.omode.channel.get(arg_0 = 1) \n
		Sets or queries the device channel for trigger source 'Operation Modes'. See Figure 'Overview of trigger IO system'. \n
			:param arg_0: OUT1 | OUTP1 | OUTPut1 | OUT2 | OUTP2 | OUTPut2 OUT1 | OUTP1 | OUTPut1 Ch1 is selected as the device channel for trigger source. OUT2 | OUTP2 | OUTPut2 Ch2 is selected as the device channel for trigger source.
			:return: arg_0: OUT1 | OUTP1 | OUTPut1 | OUT2 | OUTP2 | OUTPut2 OUT1 | OUTP1 | OUTPut1 Ch1 is selected as the device channel for trigger source. OUT2 | OUTP2 | OUTPut2 Ch2 is selected as the device channel for trigger source."""
		param = Conversions.decimal_value_to_str(arg_0)
		response = self._core.io.query_str(f'TRIGger:SEQuence:IMMediate:SOURce:OMODe:CHANnel? {param}')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Source:
	"""Source commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, arg_0: int, arg_1: enums.DioOutSource) -> None:
		"""SCPI: DIO:OUTPut:SOURce \n
		Snippet: driver.dio.output.source.set(arg_0 = 1, arg_1 = enums.DioOutSource.FORCed) \n
		Sets or queries the digital output source. See 'operation modes' in Figure 'Overview of trigger IO system'. \n
			:param arg_0: 1 Channel selection for the digital output source.
			:param arg_1: OUTPut | TRIGger | FORCed OUTPut Selected channel output is used as the digital output source. TRIGger Selected channel external trigger signal is used as the digital output source. FORCed Selected output is forced to high level and can be switched by method RsNgx.Dio.Output.State.set command.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Integer), ArgSingle('arg_1', arg_1, DataType.Enum, enums.DioOutSource))
		self._core.io.write_with_opc(f'DIO:OUTPut:SOURce {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, arg_0: int) -> enums.DioOutSource:
		"""SCPI: DIO:OUTPut:SOURce \n
		Snippet: value: enums.DioOutSource = driver.dio.output.source.get(arg_0 = 1) \n
		Sets or queries the digital output source. See 'operation modes' in Figure 'Overview of trigger IO system'. \n
			:param arg_0: 1 Channel selection for the digital output source.
			:return: arg_1: OUTPut | TRIGger | FORCed OUTPut Selected channel output is used as the digital output source. TRIGger Selected channel external trigger signal is used as the digital output source. FORCed Selected output is forced to high level and can be switched by method RsNgx.Dio.Output.State.set command."""
		param = Conversions.decimal_value_to_str(arg_0)
		response = self._core.io.query_str_with_opc(f'DIO:OUTPut:SOURce? {param}')
		return Conversions.str_to_scalar_enum(response, enums.DioOutSource)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delay:
	"""Delay commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("delay", core, parent)

	def get_initial(self) -> float:
		"""SCPI: [SOURce]:CURRent:PROTection:DELay:INITial \n
		Snippet: value: float = driver.source.current.protection.delay.get_initial() \n
		Sets or queries the initial fuse delay time once output turns on. \n
			:return: voltage: No help available
		"""
		response = self._core.io.query_str('SOURce:CURRent:PROTection:DELay:INITial?')
		return Conversions.str_to_float(response)

	def set_initial(self, voltage: float) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection:DELay:INITial \n
		Snippet: driver.source.current.protection.delay.set_initial(voltage = 1.0) \n
		Sets or queries the initial fuse delay time once output turns on. \n
			:param voltage: No help available
		"""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:CURRent:PROTection:DELay:INITial {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce]:CURRent:PROTection:DELay \n
		Snippet: value: float = driver.source.current.protection.delay.get_value() \n
		Sets or queries the fuse delay time. \n
			:return: voltage: No help available
		"""
		response = self._core.io.query_str('SOURce:CURRent:PROTection:DELay?')
		return Conversions.str_to_float(response)

	def set_value(self, voltage: float) -> None:
		"""SCPI: [SOURce]:CURRent:PROTection:DELay \n
		Snippet: driver.source.current.protection.delay.set_value(voltage = 1.0) \n
		Sets or queries the fuse delay time. \n
			:param voltage: No help available
		"""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:CURRent:PROTection:DELay {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 3 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	@property
	def range(self):
		"""range commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_range'):
			from .Range import Range
			self._range = Range(self._core, self._cmd_group)
		return self._range



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	@property
	def ch(self):
		"""ch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ch'):
			from .Ch import Ch
			self._ch = Ch(self._core, self._cmd_group)
		return self._ch

	@property
	def select(self):
		"""select commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_select'):
			from .Select import Select
			self._select = Select(self._core, self._cmd_group)
		return self._select

	def get_general(self) -> bool:
		"""SCPI: TRACking[:ENABle]:GENeral \n
		Snippet: value: bool = driver.tracking.enable.get_general() \n
		Sets or queries the status of the master tracking state. \n
			:return: arg_0:
				- 0: Master tracking is disabled
				- 1: Master tracking is enabled"""
		response = self._core.io.query_str('TRACking:ENABle:GENeral?')
		return Conversions.str_to_bool(response)

	def set_general(self, arg_0: bool) -> None:
		"""SCPI: TRACking[:ENABle]:GENeral \n
		Snippet: driver.tracking.enable.set_general(arg_0 = False) \n
		Sets or queries the status of the master tracking state. \n
			:param arg_0:
				- 0: Master tracking is disabled
				- 1: Master tracking is enabled"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'TRACking:ENABle:GENeral {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Channel:
	"""Channel commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("channel", core, parent)

	def get_state(self) -> bool:
		"""SCPI: LOG:CHANnel[:STATe] \n
		Snippet: value: bool = driver.log.channel.get_state() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('LOG:CHANnel:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: LOG:CHANnel[:STATe] \n
		Snippet: driver.log.channel.set_state(arg_0 = False) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'LOG:CHANnel:STATe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fname:
	"""Fname commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fname", core, parent)

	def set(self, arg_0: str, arg_1: enums.Filename = None) -> None:
		"""SCPI: ARBitrary:BLOCk:FNAMe \n
		Snippet: driver.arbitrary.block.fname.set(arg_0 = r1, arg_1 = enums.Filename.DEF) \n
		Sets or queries the filename for block of arbitrary data. \n
			:param arg_0: No help available
			:param arg_1: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.RawString), ArgSingle('arg_1', arg_1, DataType.Enum, enums.Filename, is_optional=True))
		self._core.io.write(f'ARBitrary:BLOCk:FNAMe {param}'.rstrip())

	def get(self, arg_0: str, arg_1: enums.Filename = None) -> str:
		"""SCPI: ARBitrary:BLOCk:FNAMe \n
		Snippet: value: str = driver.arbitrary.block.fname.get(arg_0 = r1, arg_1 = enums.Filename.DEF) \n
		Sets or queries the filename for block of arbitrary data. \n
			:param arg_0: No help available
			:param arg_1: No help available
			:return: arg_0: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.RawString), ArgSingle('arg_1', arg_1, DataType.Enum, enums.Filename, is_optional=True))
		response = self._core.io.query_str(f'ARBitrary:BLOCk:FNAMe? {param}'.rstrip())
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Alimit:
	"""Alimit commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("alimit", core, parent)

	@property
	def upper(self):
		"""upper commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_upper'):
			from .Upper import Upper
			self._upper = Upper(self._core, self._cmd_group)
		return self._upper

	@property
	def lower(self):
		"""lower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lower'):
			from .Lower import Lower
			self._lower = Lower(self._core, self._cmd_group)
		return self._lower



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dvm:
	"""Dvm commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dvm", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:VOLTage:DVM[:STATe] \n
		Snippet: value: bool = driver.source.voltage.dvm.get_state() \n
		Sets or queries digital voltmeter measurements. \n
			:return: arg_0: 1 Enables digital voltmeter measurement. 0 Disables digital voltmeter measurement.
		"""
		response = self._core.io.query_str_with_opc('SOURce:VOLTage:DVM:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: [SOURce]:VOLTage:DVM[:STATe] \n
		Snippet: driver.source.voltage.dvm.set_state(arg_0 = False) \n
		Sets or queries digital voltmeter measurements. \n
			:param arg_0: 1 Enables digital voltmeter measurement. 0 Disables digital voltmeter measurement.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'SOURce:VOLTage:DVM:STATe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Communicate:
	"""Communicate commands group definition. 26 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("communicate", core, parent)

	@property
	def socket(self):
		"""socket commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_socket'):
			from .Socket import Socket
			self._socket = Socket(self._core, self._cmd_group)
		return self._socket

	@property
	def wlan(self):
		"""wlan commands group. 2 Sub-classes, 7 commands."""
		if not hasattr(self, '_wlan'):
			from .Wlan import Wlan
			self._wlan = Wlan(self._core, self._cmd_group)
		return self._wlan

	@property
	def lan(self):
		"""lan commands group. 2 Sub-classes, 8 commands."""
		if not hasattr(self, '_lan'):
			from .Lan import Lan
			self._lan = Lan(self._core, self._cmd_group)
		return self._lan



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WarningPy:
	"""WarningPy commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("warningPy", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import Immediate
			self._immediate = Immediate(self._core, self._cmd_group)
		return self._immediate

	def get_state(self) -> bool:
		"""SCPI: SYSTem:BEEPer:WARNing:STATe \n
		Snippet: value: bool = driver.system.beeper.warningPy.get_state() \n
		Sets or queries 'error/warning' beeper tone state. \n
			:return: warning_beep_state: No help available
		"""
		response = self._core.io.query_str('SYSTem:BEEPer:WARNing:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, warning_beep_state: bool) -> None:
		"""SCPI: SYSTem:BEEPer:WARNing:STATe \n
		Snippet: driver.system.beeper.warningPy.set_state(warning_beep_state = False) \n
		Sets or queries 'error/warning' beeper tone state. \n
			:param warning_beep_state:
				- 1: Beep sound for 'error/warning' is enabled.
				- 0: Beep sound for 'error/warning' is disabled."""
		param = Conversions.bool_to_str(warning_beep_state)
		self._core.io.write(f'SYSTem:BEEPer:WARNing:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Immediate:
	"""Immediate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def get_amplitude(self) -> float:
		"""SCPI: [SOURce]:RESistance[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: value: float = driver.source.resistance.level.immediate.get_amplitude() \n
		Sets or queries the constant resistance target value. \n
			:return: current: No help available
		"""
		response = self._core.io.query_str('SOURce:RESistance:LEVel:IMMediate:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, current: float) -> None:
		"""SCPI: [SOURce]:RESistance[:LEVel][:IMMediate][:AMPLitude] \n
		Snippet: driver.source.resistance.level.immediate.set_amplitude(current = 1.0) \n
		Sets or queries the constant resistance target value. \n
			:param current: No help available
		"""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SOURce:RESistance:LEVel:IMMediate:AMPLitude {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tripped:
	"""Tripped commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tripped", core, parent)

	def clear(self) -> None:
		"""SCPI: FUSE:TRIPped:CLEar \n
		Snippet: driver.fuse.tripped.clear() \n
		Resets the OCP state of the selected channel. If an OCP event has occurred before, the reset also erases the message on
		the display. \n
		"""
		self._core.io.write(f'FUSE:TRIPped:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: FUSE:TRIPped:CLEar \n
		Snippet: driver.fuse.tripped.clear_with_opc() \n
		Resets the OCP state of the selected channel. If an OCP event has occurred before, the reset also erases the message on
		the display. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'FUSE:TRIPped:CLEar', opc_timeout_ms)

	def get_value(self) -> bool:
		"""SCPI: FUSE:TRIPped \n
		Snippet: value: bool = driver.fuse.tripped.get_value() \n
		Queries the OCP state of the selected channel. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('FUSE:TRIPped?')
		return Conversions.str_to_bool(response)



from enum import Enum
# noinspection PyPep8Naming
from .Internal.RepeatedCapability import VALUE_DEFAULT as DefaultRepCap
# noinspection PyPep8Naming
from .Internal.RepeatedCapability import VALUE_EMPTY as EmptyRepCap


# noinspection SpellCheckingInspection
class Channel(Enum):
	"""Repeated capability Channel"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4


# noinspection SpellCheckingInspection
class DigitalIo(Enum):
	"""Repeated capability DigitalIo"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Step:
	"""Step commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("step", core, parent)

	@property
	def increment(self):
		"""increment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_increment'):
			from .Increment import Increment
			self._increment = Increment(self._core, self._cmd_group)
		return self._increment



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Range:
	"""Range commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("range", core, parent)

	def get_upper(self) -> float:
		"""SCPI: SENSe:CURRent:RANGe[:UPPer] \n
		Snippet: value: float = driver.sense.current.range.get_upper() \n
		Sets or queries the current range for measurement. There is a selection of 10 A, 1 A, 100 mA and 10 mA range. \n
			:return: arg_0: Defines the current range for measurement (10 A, 1 A, 100 mA and 10 mA) . Unit: A
		"""
		response = self._core.io.query_str('SENSe:CURRent:RANGe:UPPer?')
		return Conversions.str_to_float(response)

	def set_upper(self, arg_0: float) -> None:
		"""SCPI: SENSe:CURRent:RANGe[:UPPer] \n
		Snippet: driver.sense.current.range.set_upper(arg_0 = 1.0) \n
		Sets or queries the current range for measurement. There is a selection of 10 A, 1 A, 100 mA and 10 mA range. \n
			:param arg_0: Defines the current range for measurement (10 A, 1 A, 100 mA and 10 mA) . Unit: A
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'SENSe:CURRent:RANGe:UPPer {param}')

	def get_lower(self) -> float:
		"""SCPI: SENSe:CURRent:RANGe:LOWer \n
		Snippet: value: float = driver.sense.current.range.get_lower() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SENSe:CURRent:RANGe:LOWer?')
		return Conversions.str_to_float(response)

	def set_lower(self, arg_0: float) -> None:
		"""SCPI: SENSe:CURRent:RANGe:LOWer \n
		Snippet: driver.sense.current.range.set_lower(arg_0 = 1.0) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'SENSe:CURRent:RANGe:LOWer {param}')

	def get_auto(self) -> bool:
		"""SCPI: SENSe:CURRent:RANGe:AUTO \n
		Snippet: value: bool = driver.sense.current.range.get_auto() \n
		Sets or queries auto range for current measurement accuracy. \n
			:return: arg_0: 1 Enables auto range for current. 0 Disables auto range for current.
		"""
		response = self._core.io.query_str('SENSe:CURRent:RANGe:AUTO?')
		return Conversions.str_to_bool(response)

	def set_auto(self, arg_0: bool) -> None:
		"""SCPI: SENSe:CURRent:RANGe:AUTO \n
		Snippet: driver.sense.current.range.set_auto(arg_0 = False) \n
		Sets or queries auto range for current measurement accuracy. \n
			:param arg_0: 1 Enables auto range for current. 0 Disables auto range for current.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SENSe:CURRent:RANGe:AUTO {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Event:
	"""Event commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("event", core, parent)

	def get(self, channel=repcap.Channel.Default) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument:ISUMmary<Channel>[:EVENt] \n
		Snippet: value: int = driver.status.questionable.instrument.isummary.event.get(channel = repcap.Channel.Default) \n
		Returns the contents of the EVENt part of the status register to check whether an event has occurred since the last
		reading. Reading an EVENt register deletes its contents. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
			:return: result: Event bits in decimal representation"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'STATus:QUEStionable:INSTrument:ISUMmary{channel_cmd_val}:EVENt?')
		return Conversions.str_to_int(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Touch:
	"""Touch commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("touch", core, parent)

	def get_state(self) -> bool:
		"""SCPI: SYSTem:TOUCh[:STATe] \n
		Snippet: value: bool = driver.system.touch.get_state() \n
		Enables or disables touch interface beep. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:TOUCh:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:TOUCh[:STATe] \n
		Snippet: driver.system.touch.set_state(arg_0 = False) \n
		Enables or disables touch interface beep. \n
			:param arg_0:
				- 1: Touch interface beep is activated.
				- 0: Touch interface beep is deactivated."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:TOUCh:STATe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	def set(self, arg_0: int, channel=repcap.Channel.Default) -> None:
		"""SCPI: STATus:OPERation:INSTrument:ISUMmary<Channel>:ENABle \n
		Snippet: driver.status.operation.instrument.isummary.enable.set(arg_0 = 1, channel = repcap.Channel.Default) \n
		Controls or queries the ENABle part of the STATus:OPERation register. The ENABle defines which events in the EVENt part
		of the status register are forwarded to the OPERation summary bit (bit 7) of the status byte. The status byte can be used
		to create a service request. \n
			:param arg_0: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'STATus:OPERation:INSTrument:ISUMmary{channel_cmd_val}:ENABle {param}')

	def get(self, channel=repcap.Channel.Default) -> int:
		"""SCPI: STATus:OPERation:INSTrument:ISUMmary<Channel>:ENABle \n
		Snippet: value: int = driver.status.operation.instrument.isummary.enable.get(channel = repcap.Channel.Default) \n
		Controls or queries the ENABle part of the STATus:OPERation register. The ENABle defines which events in the EVENt part
		of the status register are forwarded to the OPERation summary bit (bit 7) of the status byte. The status byte can be used
		to create a service request. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
			:return: arg_0: No help available"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'STATus:OPERation:INSTrument:ISUMmary{channel_cmd_val}:ENABle?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, arg_0: bool) -> None:
		"""SCPI: OUTPut:TRIGgered[:STATe] \n
		Snippet: driver.output.triggered.state.set(arg_0 = False) \n
		Enables or disables the triggered event for output. \n
			:param arg_0: 1 Trigger is enabled. 0 Trigger is disabled.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:TRIGgered:STATe {param}')

	def get(self) -> bool:
		"""SCPI: OUTPut:TRIGgered[:STATe] \n
		Snippet: value: bool = driver.output.triggered.state.get() \n
		Enables or disables the triggered event for output. \n
			:return: arg_0: 1 Trigger is enabled. 0 Trigger is disabled."""
		response = self._core.io.query_str_with_opc(f'OUTPut:TRIGgered:STATe?')
		return Conversions.str_to_bool(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Measure:
	"""Measure commands group definition. 21 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("measure", core, parent)

	@property
	def voltage(self):
		"""voltage commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_voltage'):
			from .Voltage import Voltage
			self._voltage = Voltage(self._core, self._cmd_group)
		return self._voltage

	@property
	def scalar(self):
		"""scalar commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_scalar'):
			from .Scalar import Scalar
			self._scalar = Scalar(self._core, self._cmd_group)
		return self._scalar



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Behavior:
	"""Behavior commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("behavior", core, parent)

	def set(self, arg_0: str) -> None:
		"""SCPI: OUTPut:TRIGgered:BEHavior \n
		Snippet: driver.output.triggered.behavior.set(arg_0 = r1) \n
		Sets or queries output behavior when a trigger event occurs. \n
			:param arg_0: ON | OFF | GATed | list ON Output is set on when a trigger event occurs. OFF Output is set off when a trigger event occurs. GATed Output is set gated when a trigger event occurs.
		"""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:TRIGgered:BEHavior {param}')

	def get(self) -> str:
		"""SCPI: OUTPut:TRIGgered:BEHavior \n
		Snippet: value: str = driver.output.triggered.behavior.get() \n
		Sets or queries output behavior when a trigger event occurs. \n
			:return: arg_0: ON | OFF | GATed | list ON Output is set on when a trigger event occurs. OFF Output is set off when a trigger event occurs. GATed Output is set gated when a trigger event occurs."""
		response = self._core.io.query_str_with_opc(f'OUTPut:TRIGgered:BEHavior?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Model:
	"""Model commands group definition. 11 total commands, 3 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("model", core, parent)

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Fname import Fname
			self._fname = Fname(self._core, self._cmd_group)
		return self._fname

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._cmd_group)
		return self._data

	@property
	def current(self):
		"""current commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current

	def save(self) -> None:
		"""SCPI: BATTery:MODel:SAVE \n
		Snippet: driver.battery.model.save() \n
		Saves the current battery model to a file \n
		"""
		self._core.io.write(f'BATTery:MODel:SAVE')

	def save_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: BATTery:MODel:SAVE \n
		Snippet: driver.battery.model.save_with_opc() \n
		Saves the current battery model to a file \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'BATTery:MODel:SAVE', opc_timeout_ms)

	def load(self) -> None:
		"""SCPI: BATTery:MODel:LOAD \n
		Snippet: driver.battery.model.load() \n
		Loads a battery model for editing. \n
		"""
		self._core.io.write(f'BATTery:MODel:LOAD')

	def load_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: BATTery:MODel:LOAD \n
		Snippet: driver.battery.model.load_with_opc() \n
		Loads a battery model for editing. \n
		Same as load, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'BATTery:MODel:LOAD', opc_timeout_ms)

	def set_transfer(self, arg_0: int) -> None:
		"""SCPI: BATTery:MODel:TRANsfer \n
		Snippet: driver.battery.model.set_transfer(arg_0 = 1) \n
		Transfers the loaded battery model into the channel. \n
			:param arg_0: 1 | 2
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:MODel:TRANsfer {param}')

	def get_capacity(self) -> float:
		"""SCPI: BATTery:MODel:CAPacity \n
		Snippet: value: float = driver.battery.model.get_capacity() \n
		Sets or queries the battery model capacity. \n
			:return: arg_0: Sets the battery model capacity.
		"""
		response = self._core.io.query_str('BATTery:MODel:CAPacity?')
		return Conversions.str_to_float(response)

	def set_capacity(self, arg_0: float) -> None:
		"""SCPI: BATTery:MODel:CAPacity \n
		Snippet: driver.battery.model.set_capacity(arg_0 = 1.0) \n
		Sets or queries the battery model capacity. \n
			:param arg_0: Sets the battery model capacity.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:MODel:CAPacity {param}')

	def get_isoc(self) -> float:
		"""SCPI: BATTery:MODel:ISOC \n
		Snippet: value: float = driver.battery.model.get_isoc() \n
		Sets or queries the initial state of charge (SoC) of the battery model. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('BATTery:MODel:ISOC?')
		return Conversions.str_to_float(response)

	def set_isoc(self, arg_0: float) -> None:
		"""SCPI: BATTery:MODel:ISOC \n
		Snippet: driver.battery.model.set_isoc(arg_0 = 1.0) \n
		Sets or queries the initial state of charge (SoC) of the battery model. \n
			:param arg_0: Initial state of charge (SoC) for the battery model.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'BATTery:MODel:ISOC {param}')

	def clear(self) -> None:
		"""SCPI: BATTery:MODel:CLEar \n
		Snippet: driver.battery.model.clear() \n
		Clears the current battery model. \n
		"""
		self._core.io.write(f'BATTery:MODel:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: BATTery:MODel:CLEar \n
		Snippet: driver.battery.model.clear_with_opc() \n
		Clears the current battery model. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'BATTery:MODel:CLEar', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ch:
	"""Ch commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ch", core, parent)

	def set(self, arg_0: bool, channel=repcap.Channel.Nr1) -> None:
		"""SCPI: TRACking[:ENABle]:CH<CHANNEL> \n
		Snippet: driver.tracking.enable.ch.set(arg_0 = False, channel = repcap.Channel.Nr1) \n
		Sets or queries the tracking status on selected channel. \n
			:param arg_0:
				- 0: Tracking is disabled on specified channel.
				- 1: Tracking is enabled on specified channel.
			:param channel: optional repeated capability selector. Default value: Nr1"""
		param = Conversions.bool_to_str(arg_0)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'TRACking:ENABle:CH{channel_cmd_val} {param}')

	def get(self, channel=repcap.Channel.Nr1) -> bool:
		"""SCPI: TRACking[:ENABle]:CH<CHANNEL> \n
		Snippet: value: bool = driver.tracking.enable.ch.get(channel = repcap.Channel.Nr1) \n
		Sets or queries the tracking status on selected channel. \n
			:param channel: optional repeated capability selector. Default value: Nr1
			:return: arg_0:
				- 0: Tracking is disabled on specified channel.
				- 1: Tracking is enabled on specified channel."""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'TRACking:ENABle:CH{channel_cmd_val}?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Default:
	"""Default commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("default", core, parent)

	def save(self, file_path: str = None) -> None:
		"""SCPI: SYSTem:SETTing:DEFault:SAVE \n
		Snippet: driver.system.setting.default.save(file_path = '1') \n
		No command help available \n
			:param file_path: No help available
		"""
		param = ''
		if file_path:
			param = Conversions.value_to_quoted_str(file_path)
		self._core.io.write(f'SYSTem:SETTing:DEFault:SAVE {param}'.strip())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pin:
	"""Pin commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pin", core, parent)

	def set(self, arg_0: enums.TriggerDioSource) -> None:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce:DIO:PIN \n
		Snippet: driver.trigger.sequence.immediate.source.dio.pin.set(arg_0 = enums.TriggerDioSource.EXT) \n
		Sets or queries the DIO pin to trigger on for trigger source 'Digital In Channel'. See Figure 'Overview of trigger IO
		system'. \n
			:param arg_0: IN | EXT IN Pin 3 of DIO connector is monitored. EXT Pin 2 (Ch1) of DIO connector is monitored.
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.TriggerDioSource)
		self._core.io.write(f'TRIGger:SEQuence:IMMediate:SOURce:DIO:PIN {param}')

	# noinspection PyTypeChecker
	def get(self, arg_0: enums.TriggerDioSource) -> enums.TriggerDioSource:
		"""SCPI: TRIGger[:SEQuence][:IMMediate]:SOURce:DIO:PIN \n
		Snippet: value: enums.TriggerDioSource = driver.trigger.sequence.immediate.source.dio.pin.get(arg_0 = enums.TriggerDioSource.EXT) \n
		Sets or queries the DIO pin to trigger on for trigger source 'Digital In Channel'. See Figure 'Overview of trigger IO
		system'. \n
			:param arg_0: IN | EXT IN Pin 3 of DIO connector is monitored. EXT Pin 2 (Ch1) of DIO connector is monitored.
			:return: arg_0: IN | EXT IN Pin 3 of DIO connector is monitored. EXT Pin 2 (Ch1) of DIO connector is monitored."""
		param = Conversions.enum_scalar_to_str(arg_0, enums.TriggerDioSource)
		response = self._core.io.query_str(f'TRIGger:SEQuence:IMMediate:SOURce:DIO:PIN? {param}')
		return Conversions.str_to_scalar_enum(response, enums.TriggerDioSource)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voltage:
	"""Voltage commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("voltage", core, parent)

	def get_dvm(self) -> float:
		"""SCPI: MEASure:VOLTage:DVM \n
		Snippet: value: float = driver.measure.voltage.get_dvm() \n
		Queries the voltmeter measurement (if DVM is enabled) . The DVM is available only with NGU201 model equipped with R&S
		NGU-K104 (P/N: 3663.0390.02) . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:VOLTage:DVM?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Beeper:
	"""Beeper commands group definition. 8 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("beeper", core, parent)

	@property
	def output(self):
		"""output commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_output'):
			from .Output import Output
			self._output = Output(self._core, self._cmd_group)
		return self._output

	@property
	def complete(self):
		"""complete commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_complete'):
			from .Complete import Complete
			self._complete = Complete(self._core, self._cmd_group)
		return self._complete

	@property
	def warningPy(self):
		"""warningPy commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_warningPy'):
			from .WarningPy import WarningPy
			self._warningPy = WarningPy(self._core, self._cmd_group)
		return self._warningPy

	@property
	def protection(self):
		"""protection commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_protection'):
			from .Protection import Protection
			self._protection = Protection(self._core, self._cmd_group)
		return self._protection

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Point:
	"""Point commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("point", core, parent)

	def set(self, arg_0: int) -> None:
		"""SCPI: CALibration:POINt \n
		Snippet: driver.calibration.point.set(arg_0 = 1) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'CALibration:POINt {param}')

	def get(self, arg_0: int) -> int:
		"""SCPI: CALibration:POINt \n
		Snippet: value: int = driver.calibration.point.get(arg_0 = 1) \n
		No command help available \n
			:param arg_0: No help available
			:return: arg_0: No help available"""
		param = Conversions.decimal_value_to_str(arg_0)
		response = self._core.io.query_str(f'CALibration:POINt? {param}')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	def set(self, arg_0: int, channel=repcap.Channel.Default) -> None:
		"""SCPI: STATus:QUEStionable:INSTrument:ISUMmary<Channel>:ENABle \n
		Snippet: driver.status.questionable.instrument.isummary.enable.set(arg_0 = 1, channel = repcap.Channel.Default) \n
		Sets or queries the enable mask that allows true conditions in the EVENt part to be reported in the summary bit. If a bit
		in the ENABle part is 1, and the corresponding EVENt bit is true, a positive transition occurs in the summary bit. This
		transition is reported to the next higher level. \n
			:param arg_0: Bit mask in decimal representation
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'STATus:QUEStionable:INSTrument:ISUMmary{channel_cmd_val}:ENABle {param}')

	def get(self, channel=repcap.Channel.Default) -> int:
		"""SCPI: STATus:QUEStionable:INSTrument:ISUMmary<Channel>:ENABle \n
		Snippet: value: int = driver.status.questionable.instrument.isummary.enable.get(channel = repcap.Channel.Default) \n
		Sets or queries the enable mask that allows true conditions in the EVENt part to be reported in the summary bit. If a bit
		in the ENABle part is 1, and the corresponding EVENt bit is true, a positive transition occurs in the summary bit. This
		transition is reported to the next higher level. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
			:return: arg_0: No help available"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'STATus:QUEStionable:INSTrument:ISUMmary{channel_cmd_val}:ENABle?')
		return Conversions.str_to_int(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def get(self, arg_0: str) -> str:
		"""SCPI: DATA:DATA \n
		Snippet: value: str = driver.data.data.get(arg_0 = '1') \n
		Returns the logging file data of the selected file. If manual trigger mode (trigger via TRIG function) is used, the
		logging function has to be activated. Without activating the logging function in the manual trigger mode, the instrument
		is not able to save a logging file internally or on the USB stick. \n
			:param arg_0: Filepath of the logging file data.
			:return: result: No help available"""
		param = Conversions.value_to_quoted_str(arg_0)
		response = self._core.io.query_str(f'DATA:DATA? {param}')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def get_capacitance(self) -> str:
		"""SCPI: OUTPut:MODE:CAPacitance \n
		Snippet: value: str = driver.output.mode.get_capacitance() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:MODE:CAPacitance?')
		return trim_str_response(response)

	def set_capacitance(self, arg_0: str) -> None:
		"""SCPI: OUTPut:MODE:CAPacitance \n
		Snippet: driver.output.mode.set_capacitance(arg_0 = r1) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:MODE:CAPacitance {param}')

	def get_value(self) -> str:
		"""SCPI: OUTPut:MODE \n
		Snippet: value: str = driver.output.mode.get_value() \n
		Sets or queries the output mode. \n
			:return: arg_0: AUTO | SINK | SOURce | list AUTO If operates in auto mode, the R&S NGU goes into sink or source mode depending on the voltage across the output terminal. If voltage across the output terminal exceeds the set voltage, current flows into the instrument, e.g. the instrument is now operating in sink mode; vv if voltage across output terminal is below set voltage, instrument operates as a source mode. SINK If operates in sink mode, current flows into the instrument. On display, current is shown as negative current. SOURce If operates in source mode, current flows out from the instrument.
		"""
		response = self._core.io.query_str_with_opc('OUTPut:MODE?')
		return trim_str_response(response)

	def set_value(self, arg_0: str) -> None:
		"""SCPI: OUTPut:MODE \n
		Snippet: driver.output.mode.set_value(arg_0 = r1) \n
		Sets or queries the output mode. \n
			:param arg_0: AUTO | SINK | SOURce | list AUTO If operates in auto mode, the R&S NGU goes into sink or source mode depending on the voltage across the output terminal. If voltage across the output terminal exceeds the set voltage, current flows into the instrument, e.g. the instrument is now operating in sink mode; vv if voltage across output terminal is below set voltage, instrument operates as a source mode. SINK If operates in sink mode, current flows into the instrument. On display, current is shown as negative current. SOURce If operates in source mode, current flows out from the instrument.
		"""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:MODE {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Instrument:
	"""Instrument commands group definition. 10 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("instrument", core, parent)

	@property
	def isummary(self):
		"""isummary commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_isummary'):
			from .Isummary import Isummary
			self._isummary = Isummary(self._core, self._cmd_group)
		return self._isummary

	def get_event(self) -> int:
		"""SCPI: STATus:OPERation:INSTrument[:EVENt] \n
		Snippet: value: int = driver.status.operation.instrument.get_event() \n
		Returns the contents of the EVENt part of the status register to check whether an event has occurred since the last
		reading. Reading an EVENt register deletes its contents. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:INSTrument:EVENt?')
		return Conversions.str_to_int(response)

	def get_condition(self) -> int:
		"""SCPI: STATus:OPERation:INSTrument:CONDition \n
		Snippet: value: int = driver.status.operation.instrument.get_condition() \n
		Returns the contents of the CONDition part of the status register to check for operation instrument or measurement states.
		Reading the CONDition registers does not delete the contents. \n
			:return: result: Condition bits in decimal representation.
		"""
		response = self._core.io.query_str('STATus:OPERation:INSTrument:CONDition?')
		return Conversions.str_to_int(response)

	def get_ptransition(self) -> int:
		"""SCPI: STATus:OPERation:INSTrument:PTRansition \n
		Snippet: value: int = driver.status.operation.instrument.get_ptransition() \n
		Sets or queries the positive transition filter. Setting a bit in the positive transition filter shall cause a 0 to 1
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:INSTrument:PTRansition?')
		return Conversions.str_to_int(response)

	def set_ptransition(self, arg_0: int) -> None:
		"""SCPI: STATus:OPERation:INSTrument:PTRansition \n
		Snippet: driver.status.operation.instrument.set_ptransition(arg_0 = 1) \n
		Sets or queries the positive transition filter. Setting a bit in the positive transition filter shall cause a 0 to 1
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'STATus:OPERation:INSTrument:PTRansition {param}')

	def get_ntransition(self) -> int:
		"""SCPI: STATus:OPERation:INSTrument:NTRansition \n
		Snippet: value: int = driver.status.operation.instrument.get_ntransition() \n
		Sets or queries the negative transition filter. Setting a bit in the negative transition filter shall cause a 1 to 0
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:INSTrument:NTRansition?')
		return Conversions.str_to_int(response)

	def set_ntransition(self, arg_0: int) -> None:
		"""SCPI: STATus:OPERation:INSTrument:NTRansition \n
		Snippet: driver.status.operation.instrument.set_ntransition(arg_0 = 1) \n
		Sets or queries the negative transition filter. Setting a bit in the negative transition filter shall cause a 1 to 0
		transition in the corresponding bit of the associated condition register to cause a 1 to be written in the associated bit
		of the corresponding event register. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'STATus:OPERation:INSTrument:NTRansition {param}')

	def get_enable(self) -> int:
		"""SCPI: STATus:OPERation:INSTrument:ENABle \n
		Snippet: value: int = driver.status.operation.instrument.get_enable() \n
		Controls or queries the ENABle part of the STATus:OPERation register. The ENABle defines which events in the EVENt part
		of the status register are forwarded to the OPERation summary bit (bit 7) of the status byte. The status byte can be used
		to create a service request. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:INSTrument:ENABle?')
		return Conversions.str_to_int(response)

	def set_enable(self, arg_0: int) -> None:
		"""SCPI: STATus:OPERation:INSTrument:ENABle \n
		Snippet: driver.status.operation.instrument.set_enable(arg_0 = 1) \n
		Controls or queries the ENABle part of the STATus:OPERation register. The ENABle defines which events in the EVENt part
		of the status register are forwarded to the OPERation summary bit (bit 7) of the status byte. The status byte can be used
		to create a service request. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'STATus:OPERation:INSTrument:ENABle {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fname:
	"""Fname commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fname", core, parent)

	def set(self, set_new_value: str) -> None:
		"""SCPI: LOG:FNAMe \n
		Snippet: driver.log.fname.set(set_new_value = '1') \n
		Sets or queries the filename and storage location for the data logging. \n
			:param set_new_value: No help available
		"""
		param = Conversions.value_to_quoted_str(set_new_value)
		self._core.io.write(f'LOG:FNAMe {param}')

	def get(self) -> str:
		"""SCPI: LOG:FNAMe \n
		Snippet: value: str = driver.log.fname.get() \n
		Sets or queries the filename and storage location for the data logging. \n
			:return: set_new_value: No help available"""
		response = self._core.io.query_str(f'LOG:FNAMe?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Modulation:
	"""Modulation commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("modulation", core, parent)

	@property
	def gain(self):
		"""gain commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gain'):
			from .Gain import Gain
			self._gain = Gain(self._core, self._cmd_group)
		return self._gain

	def set(self, arg_0: bool, arg_1: str = None) -> None:
		"""SCPI: [SOURce]:MODulation \n
		Snippet: driver.source.modulation.set(arg_0 = False, arg_1 = r1) \n
		No command help available \n
			:param arg_0: No help available
			:param arg_1: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Boolean), ArgSingle('arg_1', arg_1, DataType.RawString, None, is_optional=True))
		self._core.io.write(f'SOURce:MODulation {param}'.rstrip())

	def get(self, arg_0: bool, arg_1: str = None) -> bool:
		"""SCPI: [SOURce]:MODulation \n
		Snippet: value: bool = driver.source.modulation.get(arg_0 = False, arg_1 = r1) \n
		No command help available \n
			:param arg_0: No help available
			:param arg_1: No help available
			:return: arg_0: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Boolean), ArgSingle('arg_1', arg_1, DataType.RawString, None, is_optional=True))
		response = self._core.io.query_str(f'SOURce:MODulation? {param}'.rstrip())
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Increment:
	"""Increment commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("increment", core, parent)

	def set(self, desired_stepsize: float, optional_default_step_query: enums.DefaultStep = None) -> None:
		"""SCPI: [SOURce]:CURRent[:LEVel][:IMMediate]:STEP[:INCRement] \n
		Snippet: driver.source.current.level.immediate.step.increment.set(desired_stepsize = 1.0, optional_default_step_query = enums.DefaultStep.DEF) \n
		Sets or queries the incremental step size for the [SOURce:]CURRent[:LEVel][:IMMediate][:AMPLitude] command. \n
			:param desired_stepsize:
				- numeric value: Step value in A.
				- DEF | DEFault: Default value of stepsize.
			:param optional_default_step_query: Queries the default voltage step size."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('desired_stepsize', desired_stepsize, DataType.Float), ArgSingle('optional_default_step_query', optional_default_step_query, DataType.Enum, enums.DefaultStep, is_optional=True))
		self._core.io.write(f'SOURce:CURRent:LEVel:IMMediate:STEP:INCRement {param}'.rstrip())

	def get(self, optional_default_step_query: enums.DefaultStep = None) -> float:
		"""SCPI: [SOURce]:CURRent[:LEVel][:IMMediate]:STEP[:INCRement] \n
		Snippet: value: float = driver.source.current.level.immediate.step.increment.get(optional_default_step_query = enums.DefaultStep.DEF) \n
		Sets or queries the incremental step size for the [SOURce:]CURRent[:LEVel][:IMMediate][:AMPLitude] command. \n
			:param optional_default_step_query: Queries the default voltage step size.
			:return: result: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('optional_default_step_query', optional_default_step_query, DataType.Enum, enums.DefaultStep, is_optional=True))
		response = self._core.io.query_str(f'SOURce:CURRent:LEVel:IMMediate:STEP:INCRement? {param}'.rstrip())
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ramp:
	"""Ramp commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ramp", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:VOLTage:RAMP[:STATe] \n
		Snippet: value: bool = driver.source.voltage.ramp.get_state() \n
		Sets or queries the state of ramp function for the previous selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SOURce:VOLTage:RAMP:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: [SOURce]:VOLTage:RAMP[:STATe] \n
		Snippet: driver.source.voltage.ramp.set_state(arg_0 = False) \n
		Sets or queries the state of ramp function for the previous selected channel. \n
			:param arg_0:
				- 0: EasyRamp function is deactivated.
				- 1: EasyRamp function is activated."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SOURce:VOLTage:RAMP:STATe {param}')

	def get_duration(self) -> float:
		"""SCPI: [SOURce]:VOLTage:RAMP:DURation \n
		Snippet: value: float = driver.source.voltage.ramp.get_duration() \n
		Sets or queries the duration of the voltage ramp. \n
			:return: voltage: No help available
		"""
		response = self._core.io.query_str('SOURce:VOLTage:RAMP:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, voltage: float) -> None:
		"""SCPI: [SOURce]:VOLTage:RAMP:DURation \n
		Snippet: driver.source.voltage.ramp.set_duration(voltage = 1.0) \n
		Sets or queries the duration of the voltage ramp. \n
			:param voltage:
				- numeric value: Duration of the ramp function in seconds.
				- MIN | MINimum: Minimum duration of the ramp function at 0.00 s.
				- MAX | MAXimum: Maximum duration of the ramp function at 60.00 s.
				- DEF | DEFault: Default duration of the ramp function at 0.01 s."""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:VOLTage:RAMP:DURation {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Complete:
	"""Complete commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("complete", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import Immediate
			self._immediate = Immediate(self._core, self._cmd_group)
		return self._immediate

	def get_state(self) -> bool:
		"""SCPI: SYSTem:BEEPer[:COMPlete]:STATe \n
		Snippet: value: bool = driver.system.beeper.complete.get_state() \n
		Sets or queries the beeper tone. \n
			:return: beeper_state: No help available
		"""
		response = self._core.io.query_str('SYSTem:BEEPer:COMPlete:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, beeper_state: bool) -> None:
		"""SCPI: SYSTem:BEEPer[:COMPlete]:STATe \n
		Snippet: driver.system.beeper.complete.set_state(beeper_state = False) \n
		Sets or queries the beeper tone. \n
			:param beeper_state: 1 | 0 ON OFF - Control beeper is deactivated. OFF ON - Control beeper is activated.
		"""
		param = Conversions.bool_to_str(beeper_state)
		self._core.io.write(f'SYSTem:BEEPer:COMPlete:STATe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Statistic:
	"""Statistic commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("statistic", core, parent)

	def reset(self) -> None:
		"""SCPI: MEASure[:SCALar]:STATistic:RESet \n
		Snippet: driver.measure.scalar.statistic.reset() \n
		Resets the minimum, maximum and average statistic values for voltage, current, and power. Additionally this command
		resets the measured energy. \n
		"""
		self._core.io.write(f'MEASure:SCALar:STATistic:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: MEASure[:SCALar]:STATistic:RESet \n
		Snippet: driver.measure.scalar.statistic.reset_with_opc() \n
		Resets the minimum, maximum and average statistic values for voltage, current, and power. Additionally this command
		resets the measured energy. \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'MEASure:SCALar:STATistic:RESet', opc_timeout_ms)

	def get_count(self) -> int:
		"""SCPI: MEASure[:SCALar]:STATistic:COUNt \n
		Snippet: value: int = driver.measure.scalar.statistic.get_count() \n
		Returns the number of samples measured in the statistics for voltage/current/power \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('MEASure:SCALar:STATistic:COUNt?')
		return Conversions.str_to_int(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Arbitrary:
	"""Arbitrary commands group definition. 25 total commands, 6 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("arbitrary", core, parent)

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Fname import Fname
			self._fname = Fname(self._core, self._cmd_group)
		return self._fname

	@property
	def block(self):
		"""block commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_block'):
			from .Block import Block
			self._block = Block(self._core, self._cmd_group)
		return self._block

	@property
	def triggered(self):
		"""triggered commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_triggered'):
			from .Triggered import Triggered
			self._triggered = Triggered(self._core, self._cmd_group)
		return self._triggered

	@property
	def sequence(self):
		"""sequence commands group. 2 Sub-classes, 3 commands."""
		if not hasattr(self, '_sequence'):
			from .Sequence import Sequence
			self._sequence = Sequence(self._core, self._cmd_group)
		return self._sequence

	@property
	def behavior(self):
		"""behavior commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_behavior'):
			from .Behavior import Behavior
			self._behavior = Behavior(self._core, self._cmd_group)
		return self._behavior

	@property
	def priority(self):
		"""priority commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_priority'):
			from .Priority import Priority
			self._priority = Priority(self._core, self._cmd_group)
		return self._priority

	def set_transfer(self, arg_0: int) -> None:
		"""SCPI: ARBitrary:TRANsfer \n
		Snippet: driver.arbitrary.set_transfer(arg_0 = 1) \n
		Transfers the defined arbitrary table. \n
			:param arg_0: 1
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:TRANsfer {param}')

	def get_state(self) -> bool:
		"""SCPI: ARBitrary[:STATe] \n
		Snippet: value: bool = driver.arbitrary.get_state() \n
		Sets or queries the QuickArb function for the previous selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: ARBitrary[:STATe] \n
		Snippet: driver.arbitrary.set_state(arg_0 = False) \n
		Sets or queries the QuickArb function for the previous selected channel. \n
			:param arg_0:
				- 1: QuickArb function is activated.
				- 0: QuickArb function is deactivated."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'ARBitrary:STATe {param}')

	def get_data(self) -> List[float]:
		"""SCPI: ARBitrary:DATA \n
		Snippet: value: List[float] = driver.arbitrary.get_data() \n
		Sets or queries the arbitrary points for the previous selected channel. Max. 1024 arbitrary points can be defined.
		The dwell time between 2 arbitrary points is specified from 1 ms to 60 ms. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('ARBitrary:DATA?')
		return response

	def set_data(self, arg_0: List[float]) -> None:
		"""SCPI: ARBitrary:DATA \n
		Snippet: driver.arbitrary.set_data(arg_0 = [1.1, 2.2, 3.3]) \n
		Sets or queries the arbitrary points for the previous selected channel. Max. 1024 arbitrary points can be defined.
		The dwell time between 2 arbitrary points is specified from 1 ms to 60 ms. \n
			:param arg_0: Voltage and current settings depending on the instrument type. If the interpolation mode is sets to 1, it indicates that the mode is activated. If the interpolation mode is sets to 0, it indicates that the mode is not activated.
		"""
		param = Conversions.list_to_csv_str(arg_0)
		self._core.io.write(f'ARBitrary:DATA {param}')

	def get_repetitions(self) -> int:
		"""SCPI: ARBitrary:REPetitions \n
		Snippet: value: int = driver.arbitrary.get_repetitions() \n
		Sets or queries the repetition rate of the defined arbitrary waveform for the previous selected channel. Up to 65535
		repetitions are possible. If the repetition rate '0' is selected the arbitrary waveform of the previous selected channel
		is repeated infinitely. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:REPetitions?')
		return Conversions.str_to_int(response)

	def set_repetitions(self, arg_0: int) -> None:
		"""SCPI: ARBitrary:REPetitions \n
		Snippet: driver.arbitrary.set_repetitions(arg_0 = 1) \n
		Sets or queries the repetition rate of the defined arbitrary waveform for the previous selected channel. Up to 65535
		repetitions are possible. If the repetition rate '0' is selected the arbitrary waveform of the previous selected channel
		is repeated infinitely. \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:REPetitions {param}')

	def clear(self) -> None:
		"""SCPI: ARBitrary:CLEar \n
		Snippet: driver.arbitrary.clear() \n
		Clears the previous defined arbitrary waveform data for the selected channel. \n
		"""
		self._core.io.write(f'ARBitrary:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ARBitrary:CLEar \n
		Snippet: driver.arbitrary.clear_with_opc() \n
		Clears the previous defined arbitrary waveform data for the selected channel. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ARBitrary:CLEar', opc_timeout_ms)

	def save(self) -> None:
		"""SCPI: ARBitrary:SAVE \n
		Snippet: driver.arbitrary.save() \n
		Saves the current arbitrary table to a file (filename specified with method RsNgx.Arbitrary.Fname.set) . \n
		"""
		self._core.io.write(f'ARBitrary:SAVE')

	def save_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ARBitrary:SAVE \n
		Snippet: driver.arbitrary.save_with_opc() \n
		Saves the current arbitrary table to a file (filename specified with method RsNgx.Arbitrary.Fname.set) . \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ARBitrary:SAVE', opc_timeout_ms)

	def load(self) -> None:
		"""SCPI: ARBitrary:LOAD \n
		Snippet: driver.arbitrary.load() \n
		Loads an arbitrary table from a file (filename specified with method RsNgx.Arbitrary.Fname.set) \n
		"""
		self._core.io.write(f'ARBitrary:LOAD')

	def load_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ARBitrary:LOAD \n
		Snippet: driver.arbitrary.load_with_opc() \n
		Loads an arbitrary table from a file (filename specified with method RsNgx.Arbitrary.Fname.set) \n
		Same as load, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ARBitrary:LOAD', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gain:
	"""Gain commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gain", core, parent)

	def set(self, arg_0: float, arg_1: str = None) -> None:
		"""SCPI: [SOURce]:MODulation:GAIN \n
		Snippet: driver.source.modulation.gain.set(arg_0 = 1.0, arg_1 = r1) \n
		Sets or queries the modulation gain. \n
			:param arg_0: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value of the modulation gain. MIN | MINimum Minimum value of the modulation gain. MAX | MAXimum Maximum value of the modulation gain UP Increases gain by a defined step size. DOWN Decreases gain by a defined step size.
			:param arg_1: list
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Float), ArgSingle('arg_1', arg_1, DataType.RawString, None, is_optional=True))
		self._core.io.write(f'SOURce:MODulation:GAIN {param}'.rstrip())

	def get(self, arg_0: float, arg_1: str = None) -> float:
		"""SCPI: [SOURce]:MODulation:GAIN \n
		Snippet: value: float = driver.source.modulation.gain.get(arg_0 = 1.0, arg_1 = r1) \n
		Sets or queries the modulation gain. \n
			:param arg_0: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value of the modulation gain. MIN | MINimum Minimum value of the modulation gain. MAX | MAXimum Maximum value of the modulation gain UP Increases gain by a defined step size. DOWN Decreases gain by a defined step size.
			:param arg_1: list
			:return: arg_0: numeric value | MIN | MINimum | MAX | MAXimum | UP | DOWN | list numeric value Numeric value of the modulation gain. MIN | MINimum Minimum value of the modulation gain. MAX | MAXimum Maximum value of the modulation gain UP Increases gain by a defined step size. DOWN Decreases gain by a defined step size."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Float), ArgSingle('arg_1', arg_1, DataType.RawString, None, is_optional=True))
		response = self._core.io.query_str(f'SOURce:MODulation:GAIN? {param}'.rstrip())
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tracking:
	"""Tracking commands group definition. 3 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tracking", core, parent)

	@property
	def enable(self):
		"""enable commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Enable import Enable
			self._enable = Enable(self._core, self._cmd_group)
		return self._enable



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scalar:
	"""Scalar commands group definition. 20 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scalar", core, parent)

	@property
	def voltage(self):
		"""voltage commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_voltage'):
			from .Voltage import Voltage
			self._voltage = Voltage(self._core, self._cmd_group)
		return self._voltage

	@property
	def current(self):
		"""current commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current

	@property
	def energy(self):
		"""energy commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_energy'):
			from .Energy import Energy
			self._energy = Energy(self._core, self._cmd_group)
		return self._energy

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._cmd_group)
		return self._power

	@property
	def statistic(self):
		"""statistic commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_statistic'):
			from .Statistic import Statistic
			self._statistic = Statistic(self._core, self._cmd_group)
		return self._statistic



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Source:
	"""Source commands group definition. 41 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def voltage(self):
		"""voltage commands group. 7 Sub-classes, 1 commands."""
		if not hasattr(self, '_voltage'):
			from .Voltage import Voltage
			self._voltage = Voltage(self._core, self._cmd_group)
		return self._voltage

	@property
	def protection(self):
		"""protection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_protection'):
			from .Protection import Protection
			self._protection = Protection(self._core, self._cmd_group)
		return self._protection

	@property
	def current(self):
		"""current commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_current'):
			from .Current import Current
			self._current = Current(self._core, self._cmd_group)
		return self._current

	@property
	def resistance(self):
		"""resistance commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_resistance'):
			from .Resistance import Resistance
			self._resistance = Resistance(self._core, self._cmd_group)
		return self._resistance

	@property
	def modulation(self):
		"""modulation commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import Modulation
			self._modulation = Modulation(self._core, self._cmd_group)
		return self._modulation

	@property
	def priority(self):
		"""priority commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_priority'):
			from .Priority import Priority
			self._priority = Priority(self._core, self._cmd_group)
		return self._priority

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._cmd_group)
		return self._power

	@property
	def alimit(self):
		"""alimit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alimit'):
			from .Alimit import Alimit
			self._alimit = Alimit(self._core, self._cmd_group)
		return self._alimit



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	@property
	def imin(self):
		"""imin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_imin'):
			from .Imin import Imin
			self._imin = Imin(self._core, self._cmd_group)
		return self._imin

	@property
	def imax(self):
		"""imax commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_imax'):
			from .Imax import Imax
			self._imax = Imax(self._core, self._cmd_group)
		return self._imax

	def get_data(self) -> float:
		"""SCPI: CALibration:CURRent:DATA \n
		Snippet: value: float = driver.calibration.current.get_data() \n
		Set the DMM reading after setting the output current level in channel adjustment process. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('CALibration:CURRent:DATA?')
		return Conversions.str_to_float(response)

	def set_data(self, arg_0: float) -> None:
		"""SCPI: CALibration:CURRent:DATA \n
		Snippet: driver.calibration.current.set_data(arg_0 = 1.0) \n
		Set the DMM reading after setting the output current level in channel adjustment process. \n
			:param arg_0: Measured value from DMM.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'CALibration:CURRent:DATA {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sequence:
	"""Sequence commands group definition. 5 total commands, 2 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequence", core, parent)

	@property
	def transfer(self):
		"""transfer commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_transfer'):
			from .Transfer import Transfer
			self._transfer = Transfer(self._core, self._cmd_group)
		return self._transfer

	@property
	def behavior(self):
		"""behavior commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_behavior'):
			from .Behavior import Behavior
			self._behavior = Behavior(self._core, self._cmd_group)
		return self._behavior

	def get_repetitions(self) -> int:
		"""SCPI: ARBitrary:SEQuence:REPetitions \n
		Snippet: value: int = driver.arbitrary.sequence.get_repetitions() \n
		Sets or queries the number of repetitions of the arbitrary sequence \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:SEQuence:REPetitions?')
		return Conversions.str_to_int(response)

	def set_repetitions(self, arg_0: int) -> None:
		"""SCPI: ARBitrary:SEQuence:REPetitions \n
		Snippet: driver.arbitrary.sequence.set_repetitions(arg_0 = 1) \n
		Sets or queries the number of repetitions of the arbitrary sequence \n
			:param arg_0: No help available
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'ARBitrary:SEQuence:REPetitions {param}')

	def get_endpoint(self) -> int:
		"""SCPI: ARBitrary:SEQuence:ENDPoint \n
		Snippet: value: int = driver.arbitrary.sequence.get_endpoint() \n
		Queries the total number of points of the arbitrary sequence. \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('ARBitrary:SEQuence:ENDPoint?')
		return Conversions.str_to_int(response)

	def clear(self) -> None:
		"""SCPI: ARBitrary:SEQuence:CLEar \n
		Snippet: driver.arbitrary.sequence.clear() \n
		Clears the arbitrary sequence. \n
		"""
		self._core.io.write(f'ARBitrary:SEQuence:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ARBitrary:SEQuence:CLEar \n
		Snippet: driver.arbitrary.sequence.clear_with_opc() \n
		Clears the arbitrary sequence. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ARBitrary:SEQuence:CLEar', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, arg_0: int, arg_1: bool) -> None:
		"""SCPI: DIO:OUTPut[:STATe] \n
		Snippet: driver.dio.output.state.set(arg_0 = 1, arg_1 = False) \n
		Sets or queries the digital output channel selection. \n
			:param arg_0: 1 Channel selection for the digital output source.
			:param arg_1: 1 | 0 Enables or disables the digital output state.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('arg_0', arg_0, DataType.Integer), ArgSingle('arg_1', arg_1, DataType.Boolean))
		self._core.io.write_with_opc(f'DIO:OUTPut:STATe {param}'.rstrip())

	def get(self, arg_0: int) -> bool:
		"""SCPI: DIO:OUTPut[:STATe] \n
		Snippet: value: bool = driver.dio.output.state.get(arg_0 = 1) \n
		Sets or queries the digital output channel selection. \n
			:param arg_0: 1 Channel selection for the digital output source.
			:return: arg_1: 1 | 0 Enables or disables the digital output state."""
		param = Conversions.decimal_value_to_str(arg_0)
		response = self._core.io.query_str_with_opc(f'DIO:OUTPut:STATe? {param}')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ainput:
	"""Ainput commands group definition. 9 total commands, 5 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ainput", core, parent)

	@property
	def start(self):
		"""start commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_start'):
			from .Start import Start
			self._start = Start(self._core, self._cmd_group)
		return self._start

	@property
	def cancel(self):
		"""cancel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cancel'):
			from .Cancel import Cancel
			self._cancel = Cancel(self._core, self._cmd_group)
		return self._cancel

	@property
	def end(self):
		"""end commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_end'):
			from .End import End
			self._end = End(self._core, self._cmd_group)
		return self._end

	@property
	def umin(self):
		"""umin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_umin'):
			from .Umin import Umin
			self._umin = Umin(self._core, self._cmd_group)
		return self._umin

	@property
	def umax(self):
		"""umax commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_umax'):
			from .Umax import Umax
			self._umax = Umax(self._core, self._cmd_group)
		return self._umax

	def save(self) -> None:
		"""SCPI: CALibration:AINPut:SAVE \n
		Snippet: driver.calibration.ainput.save() \n
		Saves the analog input adjustment. \n
		"""
		self._core.io.write(f'CALibration:AINPut:SAVE')

	def save_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALibration:AINPut:SAVE \n
		Snippet: driver.calibration.ainput.save_with_opc() \n
		Saves the analog input adjustment. \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALibration:AINPut:SAVE', opc_timeout_ms)

	def get_data(self) -> float:
		"""SCPI: CALibration:AINPut:DATA \n
		Snippet: value: float = driver.calibration.ainput.get_data() \n
		Sets the analog input adjustment data. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('CALibration:AINPut:DATA?')
		return Conversions.str_to_float(response)

	def set_data(self, arg_0: float) -> None:
		"""SCPI: CALibration:AINPut:DATA \n
		Snippet: driver.calibration.ainput.set_data(arg_0 = 1.0) \n
		Sets the analog input adjustment data. \n
			:param arg_0: Measured value from DMM.
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		self._core.io.write(f'CALibration:AINPut:DATA {param}')

	def get_date(self) -> str:
		"""SCPI: CALibration:AINPut:DATE \n
		Snippet: value: str = driver.calibration.ainput.get_date() \n
		Returns the analog input adjustment date ('DD-MM-YY') . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('CALibration:AINPut:DATE?')
		return trim_str_response(response)

	def get_count(self) -> int:
		"""SCPI: CALibration:AINPut:COUNt \n
		Snippet: value: int = driver.calibration.ainput.get_count() \n
		Queries the number of counts performed for analog input adjustment . \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('CALibration:AINPut:COUNt?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Lan:
	"""Lan commands group definition. 10 total commands, 2 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lan", core, parent)

	@property
	def apply(self):
		"""apply commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import Apply
			self._apply = Apply(self._core, self._cmd_group)
		return self._apply

	@property
	def discard(self):
		"""discard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_discard'):
			from .Discard import Discard
			self._discard = Discard(self._core, self._cmd_group)
		return self._discard

	def get_dhcp(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:LAN:DHCP \n
		Snippet: value: bool = driver.system.communicate.lan.get_dhcp() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:DHCP?')
		return Conversions.str_to_bool(response)

	def set_dhcp(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:DHCP \n
		Snippet: driver.system.communicate.lan.set_dhcp(arg_0 = False) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:LAN:DHCP {param}')

	def get_address(self) -> str:
		"""SCPI: SYSTem:COMMunicate:LAN:ADDRess \n
		Snippet: value: str = driver.system.communicate.lan.get_address() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:ADDRess?')
		return trim_str_response(response)

	def set_address(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:ADDRess \n
		Snippet: driver.system.communicate.lan.set_address(arg_0 = '1') \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:LAN:ADDRess {param}')

	def get_smask(self) -> str:
		"""SCPI: SYSTem:COMMunicate:LAN:SMASk \n
		Snippet: value: str = driver.system.communicate.lan.get_smask() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:SMASk?')
		return trim_str_response(response)

	def set_smask(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:SMASk \n
		Snippet: driver.system.communicate.lan.set_smask(arg_0 = '1') \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:LAN:SMASk {param}')

	def get_dgateway(self) -> str:
		"""SCPI: SYSTem:COMMunicate:LAN:DGATeway \n
		Snippet: value: str = driver.system.communicate.lan.get_dgateway() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:DGATeway?')
		return trim_str_response(response)

	def set_dgateway(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:DGATeway \n
		Snippet: driver.system.communicate.lan.set_dgateway(arg_0 = '1') \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:LAN:DGATeway {param}')

	def get_hostname(self) -> str:
		"""SCPI: SYSTem:COMMunicate:LAN:HOSTname \n
		Snippet: value: str = driver.system.communicate.lan.get_hostname() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:HOSTname?')
		return trim_str_response(response)

	def set_hostname(self, arg_0: str) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:HOSTname \n
		Snippet: driver.system.communicate.lan.set_hostname(arg_0 = '1') \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_quoted_str(arg_0)
		self._core.io.write(f'SYSTem:COMMunicate:LAN:HOSTname {param}')

	def get_mac(self) -> str:
		"""SCPI: SYSTem:COMMunicate:LAN:MAC \n
		Snippet: value: str = driver.system.communicate.lan.get_mac() \n
		No command help available \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:MAC?')
		return trim_str_response(response)

	def reset(self) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:RESet \n
		Snippet: driver.system.communicate.lan.reset() \n
		No command help available \n
		"""
		self._core.io.write(f'SYSTem:COMMunicate:LAN:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:COMMunicate:LAN:RESet \n
		Snippet: driver.system.communicate.lan.reset_with_opc() \n
		No command help available \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:COMMunicate:LAN:RESet', opc_timeout_ms)

	def get_edited(self) -> str:
		"""SCPI: SYSTem:COMMunicate:LAN:EDITed \n
		Snippet: value: str = driver.system.communicate.lan.get_edited() \n
		No command help available \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:LAN:EDITed?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delay:
	"""Delay commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("delay", core, parent)

	def get_duration(self) -> float:
		"""SCPI: OUTPut:DELay:DURation \n
		Snippet: value: float = driver.output.delay.get_duration() \n
		Sets or queries the duration for output delay. \n
			:return: sequence_delay: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:DELay:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, sequence_delay: float) -> None:
		"""SCPI: OUTPut:DELay:DURation \n
		Snippet: driver.output.delay.set_duration(sequence_delay = 1.0) \n
		Sets or queries the duration for output delay. \n
			:param sequence_delay:
				- numeric value: Numeric value of the duration in seconds.
				- MIN | MINimum: Minimum value of the duration at 0.001 seconds.
				- MAX | MAXimum: Maximum value of the duration at 10.00 seconds."""
		param = Conversions.decimal_value_to_str(sequence_delay)
		self._core.io.write_with_opc(f'OUTPut:DELay:DURation {param}')

	def get_state(self) -> bool:
		"""SCPI: OUTPut:DELay[:STATe] \n
		Snippet: value: bool = driver.output.delay.get_state() \n
		Sets or queries the output delay state for the selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str_with_opc('OUTPut:DELay:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: OUTPut:DELay[:STATe] \n
		Snippet: driver.output.delay.set_state(arg_0 = False) \n
		Sets or queries the output delay state for the selected channel. \n
			:param arg_0:
				- 0: Deactivates output delay for the selected channel.
				- 1: Activates output delay for the selected channel."""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write_with_opc(f'OUTPut:DELay:STATe {param}')
